@@ -25,10 +25,10 @@ if __name__ == '__main__':
     'CFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wno-incompatible-function-pointer-types',
     'CPPFLAGS=-D__USE_MINGW_ANSI_STDIO=1',
     'CXX=clang++',
-    'CXXFLAGS=-O2 -pipe',
+    'CXXFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong',
     'FC=',
     'FFLAGS=-O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -I/clangarm64/include',
-    'LDFLAGS=-pipe',
+    'LDFLAGS=',
     'LIBS=',
     'MAKEFLAGS=-j3',
   ]
